@@ -5,6 +5,7 @@
 #' @param ... Successive results to be compared as lists.
 #' @param factor.value The $value of the list object is multiplied by factor.value to calculate BIC.
 #' @param silent If TRUE, nothing is displayed.
+#' @param FUN Function used to show values
 #' @description This function is used to compare the BIC of several outputs obtained with the same data but with different set of parameters.\cr
 #' Each object must have associated \code{logLik()} method with df and nobs attributes.\cr
 #' BIC for object x will be calculated as \code{2*factor.value*sum(logLik(x))+sum(attributes(logLik(x))$df)*log(attributes(logLik(x))$nobs))}.\cr
@@ -38,7 +39,7 @@
 #' @export
 
 
-compare_BIC <- function(..., factor.value=-1, silent=FALSE) {
+compare_BIC <- function(..., factor.value=-1, silent=FALSE, FUN=function(x) specify_decimal(x, decimals=2)) {
 
   result <- list(...)
   
@@ -91,7 +92,7 @@ compare_BIC <- function(..., factor.value=-1, silent=FALSE) {
         saw=sum(aw)
         aw<-aw/saw
         
-        out<-data.frame(cbind(BIC=bic, DeltaBIC=deltabic, Akaike_weight=aw), row.names=name)
+        out<-data.frame(cbind(BIC=FUN(bic), DeltaBIC=FUN(deltabic), Akaike_weight=FUN(aw)), row.names=name)
         if (!silent) print(paste("The lowest BIC (",sprintf("%.3f", bestbic) ,") is for series ", name[ser], " with Akaike weight=", sprintf("%.3f", aw[ser]), sep=""))
         
         return(out)
